"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "InputRightAddon", {
  enumerable: true,
  get: function () {
    return _InputGroup.InputRightAddon;
  }
});
Object.defineProperty(exports, "InputGroup", {
  enumerable: true,
  get: function () {
    return _InputGroup.InputGroup;
  }
});
Object.defineProperty(exports, "InputLeftAddon", {
  enumerable: true,
  get: function () {
    return _InputGroup.InputLeftAddon;
  }
});
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _reactNative = require("react-native");

var _native = _interopRequireDefault(require("styled-components/native"));

var _styledSystem = require("styled-system");

var _customProps = require("../../../utils/customProps");

var _Box = _interopRequireDefault(require("../Box"));

var _Text = _interopRequireDefault(require("../Text"));

var _Flex = _interopRequireDefault(require("../Flex"));

var _InputGroup = require("./InputGroup");

var _hooks = require("../../../hooks");

var _theme = require("../../../theme");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

const StyledInput = (0, _native.default)(_reactNative.TextInput)(_styledSystem.flex, _styledSystem.color, _styledSystem.space, _styledSystem.layout, _styledSystem.flexbox, _styledSystem.border, _styledSystem.typography, _customProps.customBorder, _customProps.customBackground, _customProps.customOutline, _customProps.customShadow, _customProps.customExtra, _customProps.customTypography, _customProps.customLayout);

const Input = ({
  style,
  isInvalid,
  isDisabled,
  placeholder,
  errorMessage,
  // isRequired,
  isReadOnly,
  isFullWidth,
  onFocus,
  onBlur,
  focusBorderColor,
  errorBorderColor,
  errorMessageColor,
  ariaLabel,
  accessibilityLabel,
  InputLeftElement,
  InputRightElement,
  type,
  w,
  width,
  h,
  height,
  m,
  mr,
  ml,
  mt,
  mb,
  ...props
}, ref) => {
  const layoutProps = {
    w,
    width,
    m,
    mr,
    ml,
    mt,
    mb
  };
  const [isFocused, setIsFocused] = (0, _react.useState)(false);

  const handleFocus = (focusState, callback) => {
    setIsFocused(focusState);
    callback();
  };

  const focusProps = isFocused ? {
    borderWidth: 1,
    borderColor: focusBorderColor ? focusBorderColor : 'default.200'
  } : {};
  const isInvalidProps = isInvalid ? {
    borderColor: errorBorderColor ? errorBorderColor : 'danger.600'
  } : {};
  const newProps = (0, _hooks.useThemeProps)('Input', props);
  const computedProps = {
    display: 'flex',
    flexDirection: 'row',
    ...focusProps,
    ...isInvalidProps,
    h,
    height
  };

  let [padding, rem] = _theme.themeTools.extractInObject(newProps, ['p', 'px', 'py', 'pt', 'pb', 'pl', 'pr']);

  return /*#__PURE__*/_react.default.createElement(_Box.default, _extends({
    w: isFullWidth ? '100%' : 'auto'
  }, layoutProps), /*#__PURE__*/_react.default.createElement(_Box.default, _extends({}, rem, isDisabled ? newProps._isDisabledProps : {}, computedProps, {
    style: style
  }), InputLeftElement ? /*#__PURE__*/_react.default.createElement(_Flex.default, {
    justify: "center",
    align: "center",
    left: 0
  }, InputLeftElement) : null, /*#__PURE__*/_react.default.createElement(StyledInput, _extends({}, newProps, padding, {
    flex: 1,
    secureTextEntry: type === 'password',
    accessible: true,
    accessibilityLabel: ariaLabel || accessibilityLabel,
    onKeyPress: e => {
      e.persist();
    },
    onFocus: () => {
      handleFocus(true, onFocus ? onFocus : () => {});
    },
    onBlur: () => {
      handleFocus(false, onBlur ? onBlur : () => {});
    },
    placeholder: placeholder,
    editable: isDisabled || isReadOnly ? false : true // borderRadius={50} //Remove variant props from StyledInput
    ,
    borderWidth: undefined
  }, _reactNative.Platform.OS === 'web' ? {
    disabled: isDisabled,
    cursor: isDisabled ? 'not-allowed' : 'auto'
  } : {}, {
    ref: ref
  })), InputRightElement ? /*#__PURE__*/_react.default.createElement(_Flex.default, {
    justify: "center",
    align: "center",
    right: 0
  }, InputRightElement) : null), isInvalid && errorMessage ? /*#__PURE__*/_react.default.createElement(_Text.default, {
    ml: 2,
    color: errorMessageColor ? errorMessageColor : 'danger.600'
  }, errorMessage) : null);
}; //-------------------------------- InputGroup and other Child components -------------------------------


var _default = /*#__PURE__*/_react.default.memo( /*#__PURE__*/(0, _react.forwardRef)(Input));

exports.default = _default;
//# sourceMappingURL=index.js.map