function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React, { forwardRef, useState } from 'react';
import { TextInput, Platform } from 'react-native';
import styled from 'styled-components/native';
import { border, flex, space, color, flexbox, layout, typography } from 'styled-system';
import { customBorder, customBackground, customOutline, customLayout, customExtra, customShadow, customTypography } from '../../../utils/customProps';
import Box from '../Box';
import Text from '../Text';
import Flex from '../Flex';
import { InputRightAddon, InputGroup, InputLeftAddon } from './InputGroup';
import { useThemeProps } from '../../../hooks';
import { themeTools } from '../../../theme';
const StyledInput = styled(TextInput)(flex, color, space, layout, flexbox, border, typography, customBorder, customBackground, customOutline, customShadow, customExtra, customTypography, customLayout);

const Input = ({
  style,
  isInvalid,
  isDisabled,
  placeholder,
  errorMessage,
  // isRequired,
  isReadOnly,
  isFullWidth,
  onFocus,
  onBlur,
  focusBorderColor,
  errorBorderColor,
  errorMessageColor,
  ariaLabel,
  accessibilityLabel,
  InputLeftElement,
  InputRightElement,
  type,
  w,
  width,
  h,
  height,
  m,
  mr,
  ml,
  mt,
  mb,
  ...props
}, ref) => {
  const layoutProps = {
    w,
    width,
    m,
    mr,
    ml,
    mt,
    mb
  };
  const [isFocused, setIsFocused] = useState(false);

  const handleFocus = (focusState, callback) => {
    setIsFocused(focusState);
    callback();
  };

  const focusProps = isFocused ? {
    borderWidth: 1,
    borderColor: focusBorderColor ? focusBorderColor : 'default.200'
  } : {};
  const isInvalidProps = isInvalid ? {
    borderColor: errorBorderColor ? errorBorderColor : 'danger.600'
  } : {};
  const newProps = useThemeProps('Input', props);
  const computedProps = {
    display: 'flex',
    flexDirection: 'row',
    ...focusProps,
    ...isInvalidProps,
    h,
    height
  };
  let [padding, rem] = themeTools.extractInObject(newProps, ['p', 'px', 'py', 'pt', 'pb', 'pl', 'pr']);
  return /*#__PURE__*/React.createElement(Box, _extends({
    w: isFullWidth ? '100%' : 'auto'
  }, layoutProps), /*#__PURE__*/React.createElement(Box, _extends({}, rem, isDisabled ? newProps._isDisabledProps : {}, computedProps, {
    style: style
  }), InputLeftElement ? /*#__PURE__*/React.createElement(Flex, {
    justify: "center",
    align: "center",
    left: 0
  }, InputLeftElement) : null, /*#__PURE__*/React.createElement(StyledInput, _extends({}, newProps, padding, {
    flex: 1,
    secureTextEntry: type === 'password',
    accessible: true,
    accessibilityLabel: ariaLabel || accessibilityLabel,
    onKeyPress: e => {
      e.persist();
    },
    onFocus: () => {
      handleFocus(true, onFocus ? onFocus : () => {});
    },
    onBlur: () => {
      handleFocus(false, onBlur ? onBlur : () => {});
    },
    placeholder: placeholder,
    editable: isDisabled || isReadOnly ? false : true // borderRadius={50} //Remove variant props from StyledInput
    ,
    borderWidth: undefined
  }, Platform.OS === 'web' ? {
    disabled: isDisabled,
    cursor: isDisabled ? 'not-allowed' : 'auto'
  } : {}, {
    ref: ref
  })), InputRightElement ? /*#__PURE__*/React.createElement(Flex, {
    justify: "center",
    align: "center",
    right: 0
  }, InputRightElement) : null), isInvalid && errorMessage ? /*#__PURE__*/React.createElement(Text, {
    ml: 2,
    color: errorMessageColor ? errorMessageColor : 'danger.600'
  }, errorMessage) : null);
}; //-------------------------------- InputGroup and other Child components -------------------------------


export { InputRightAddon, InputGroup, InputLeftAddon };
export default /*#__PURE__*/React.memo( /*#__PURE__*/forwardRef(Input));
//# sourceMappingURL=index.js.map